@@ -34,5 +34,23 @@ test_that("comments are treated corectly", {
                                  transformer = style_text,
                                  write_back = TRUE), NA)
 
-  # top-level test with indention
+})
+
+test_that("rplumber tags / syntax is handled properly", {
+  expect_warning(test_collection("parse_comments",
+                                 "rplumber",
+                                 transformer = style_text), NA)
+})
+
+
+test_that("hashbangs are respected", {
+  expect_warning(test_collection("parse_comments",
+                                 "shebang",
+                                 transformer = style_text), NA)
+})
+
+test_that("code chunk headers for spinning are respected", {
+  expect_warning(test_collection("parse_comments",
+                                 "spinning_code_chunk_headers",
+                                 transformer = style_text), NA)
 })
